@@ -315,6 +315,16 @@ func validateIdentityProviders(idPs []IdentityProvider) error {
 	return nil
 }
 
+type unsupportedFieldError struct {
+	ng    *NodeGroupBase
+	path  string
+	field string
+}
+
+func (ue *unsupportedFieldError) Error() string {
+	return fmt.Sprintf("%s is not supported for %s nodegroups (path=%s.%s)", ue.field, ue.ng.AMIFamily, ue.path, ue.field)
+}
+
 // ValidateNodeGroup checks compatible fields of a given nodegroup
 func ValidateNodeGroup(i int, ng *NodeGroup) error {
 	path := fmt.Sprintf("nodeGroups[%d]", i)
@@ -360,15 +370,18 @@ func ValidateNodeGroup(i int, ng *NodeGroup) error {
 
 	if IsWindowsImage(ng.AMIFamily) || ng.AMIFamily == NodeImageFamilyBottlerocket {
 		fieldNotSupported := func(field string) error {
-			return fmt.Errorf("%s is not supported for %s nodegroups (path=%s.%s)", field, ng.AMIFamily, path, field)
+			return &unsupportedFieldError{
+				ng:    ng.NodeGroupBase,
+				path:  path,
+				field: field,
+			}
 		}
 		if ng.KubeletExtraConfig != nil {
 			return fieldNotSupported("kubeletExtraConfig")
 		}
-		if ng.AMIFamily == NodeImageFamilyBottlerocket {
-			if ng.PreBootstrapCommands != nil {
-				return fieldNotSupported("preBootstrapCommands")
-			}
+		if ng.AMIFamily == NodeImageFamilyBottlerocket && ng.PreBootstrapCommands != nil {
+			return fieldNotSupported("preBootstrapCommands")
+
 		}
 		if ng.OverrideBootstrapCommand != nil {
 			return fieldNotSupported("overrideBootstrapCommand")
@@ -516,9 +529,13 @@ func validateNodeGroupIAM(iam *NodeGroupIAM, value, fieldName, path string) erro
 
 // ValidateManagedNodeGroup validates a ManagedNodeGroup and sets some defaults
 func ValidateManagedNodeGroup(ng *ManagedNodeGroup, index int) error {
-	if ng.AMIFamily != NodeImageFamilyAmazonLinux2 {
-		return fmt.Errorf("only %s is supported for Managed Nodegroups", NodeImageFamilyAmazonLinux2)
+	switch ng.AMIFamily {
+	case NodeImageFamilyAmazonLinux2, NodeImageFamilyBottlerocket, NodeImageFamilyUbuntu1804, NodeImageFamilyUbuntu2004:
+
+	default:
+		return errors.Errorf("%q is not supported for managed nodegroups", ng.AMIFamily)
 	}
+
 	path := fmt.Sprintf("managedNodeGroups[%d]", index)
 
 	if err := validateNodeGroupBase(ng.NodeGroupBase, path); err != nil {
@@ -551,7 +568,7 @@ func ValidateManagedNodeGroup(ng *ManagedNodeGroup, index int) error {
 		return fmt.Errorf("cannot use --nodes-min=%d and --nodes=%d at the same time", *ng.MinSize, *ng.DesiredCapacity)
 	}
 
-	// Ensure MaxSize is set, as it is required by the ASG cfn resource
+	// Ensure MaxSize is set, as it is required by the ASG CFN resource
 	if ng.MaxSize == nil {
 		if ng.DesiredCapacity == nil {
 			ng.MaxSize = ng.MinSize
@@ -581,6 +598,22 @@ func ValidateManagedNodeGroup(ng *ManagedNodeGroup, index int) error {
 		}
 	}
 
+	if ng.AMIFamily == NodeImageFamilyBottlerocket {
+		fieldNotSupported := func(field string) error {
+			return &unsupportedFieldError{
+				ng:    ng.NodeGroupBase,
+				path:  path,
+				field: field,
+			}
+		}
+		if ng.PreBootstrapCommands != nil {
+			return fieldNotSupported("preBootstrapCommands")
+		}
+		if ng.OverrideBootstrapCommand != nil {
+			return fieldNotSupported("overrideBootstrapCommand")
+		}
+	}
+
 	if err := validateTaints(ng.Taints); err != nil {
 		return err
 	}
@@ -619,6 +652,9 @@ func ValidateManagedNodeGroup(ng *ManagedNodeGroup, index int) error {
 		if !IsAMI(ng.AMI) {
 			return errors.Errorf("invalid AMI %q (%s.%s)", ng.AMI, path, "ami")
 		}
+		if ng.AMIFamily != NodeImageFamilyAmazonLinux2 {
+			return errors.Errorf("cannot set amiFamily to %s when using a custom AMI", ng.AMIFamily)
+		}
 		if ng.OverrideBootstrapCommand == nil {
 			return errors.Errorf("%s.overrideBootstrapCommand is required when using a custom AMI (%s.ami)", path, path)
 		}
